#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const Base64 = __importStar(require("base64-js"));
const fs = __importStar(require("fs"));
// import fetch from 'node-fetch'
// import { costPerTx } from './costants'
const core_1 = require("./core");
const utils_1 = require("./utils");
const action = process.argv[2];
if (action === 'get') {
    // fetch txs, compose, save file
    const txid = process.argv[3];
    const filename = process.argv[4];
    core_1.fetchTx(txid).then((b64str) => {
        const byteArray = Base64.toByteArray(b64str.split(',')[1]);
        fs.writeFile(filename, byteArray, 'base64', () => {
            console.log(`Done, saved ${txid} in ${filename}`);
        });
    });
}
else if (action === 'push') {
    // base64, do txs, print txid
    const filename = process.argv[3];
    function callme() {
        return __awaiter(this, void 0, void 0, function* () {
            let counter = 0;
            let nextTx = null;
            const chunks = yield core_1.prepareChunks(filename);
            for (const chunk of chunks.reverse()) {
                try {
                    const memo = utils_1.createPayload(chunk, nextTx);
                    const doneTx = yield core_1.doTx(memo);
                    const cpu = doneTx.processed.receipt.cpu_usage_us;
                    const net = doneTx.processed.receipt.net_usage_words;
                    // NOTE: needed for better cli formatting
                    console.log(`${counter}. ${nextTx}
   ${doneTx.transaction_id} cpu: ${cpu} net:${net}`);
                    nextTx = doneTx.transaction_id;
                    counter += 1;
                }
                catch (err) {
                    console.log(`eosfilestore ERROR: ${JSON.stringify(err, null, 2)}`);
                    return;
                }
            }
            console.log(`Done, uploaded ${filename} in ${nextTx}`);
        });
    }
    callme();
}
else if (action === 'cost') {
    // base64, count chunks
    const filename = process.argv[3];
    function callme() {
        return __awaiter(this, void 0, void 0, function* () {
            const chunks = yield core_1.prepareChunks(filename);
            const numTxs = chunks.length;
            const netEst = (1272 * numTxs) / 1000;
            const cpuEst = (20000 * numTxs) / 1000; // NOTE: it changes per tx
            // const cost = numTxs * costPerTx
            // const priceData = await fetch('https://api.coinmarketcap.com/v2/ticker/1765/').then(data => data.json())
            // const eosPrice = priceData.data.quotes.USD.price
            // console.log(`${numTxs} txs, ${(cost).toFixed(4)} EOS (${(cost * eosPrice).toFixed(4)} USD)`)
            console.log(`0 EOS - ${numTxs} txs / CPU: ${cpuEst} ms / NET: ${netEst} KB`);
        });
    }
    callme();
}
else if (action === '--version') {
    console.log(require('../package.json').version);
}
else { // --help
    console.log(`
eosfilestore - upload and download files on EOS Blockchain

Usage:
      eosfilestore get <txid> <my file path>
      eosfilestore cost <my file path>
      eosfilestore push <my file path>
  `);
}
